measuretools.move_measure_prolation_to_full_measure_tuplet
==========================================================

.. autofunction:: abjad.tools.measuretools.move_measure_prolation_to_full_measure_tuplet.move_measure_prolation_to_full_measure_tuplet
